@@ -27,6 +27,7 @@ import re
 import keyword
 import wx
 from wxPython.wx import *
+
 from wxPython.stc import *
 from wx.stc import *
 from utils import get_rootdir,isOsX,L2U
@@ -51,8 +52,11 @@ if os.name == 'nt' or isOsX():
 else:
     if os.path.exists(os.path.expanduser('~/GvR')):
         BASEDIR = os.path.expanduser('~/GvR/New')
-    else:
+    elif os.path.exists(os.path.expanduser('~/New')):
         BASEDIR = os.path.expanduser('~/New')
+    else:
+        BASEDIR = os.path.expanduser('~')
+        
 if wxPlatform == '__WXMSW__':
     faces = { 'times': 'Times New Roman',
               'mono' : 'Courier New',
@@ -78,7 +82,7 @@ class EditorWindow(wxFrame):
         if os.name == 'nt':
             self.lastDir = self.dirName() # see subclass
         else:
-            self.lastDir = os.path.expanduser('~/GvR')
+            self.lastDir = BASEDIR
         self.cur_file_name = self.newFileName()
         self.filePath = BASEDIR
         self.fileWasOpened = 0
@@ -133,7 +137,7 @@ class EditorWindow(wxFrame):
         # Python styles
         self.textctrl.SetLexer(STC_LEX_PYTHON)
         # Added some gvr keywords
-        #self.textctrl.SetKeyWords(0, self.keywords())
+        self.textctrl.SetKeyWords(0, self.keywords())
         #self.textctrl.SetKeyWords(0, " ".join(("E","N","S","W")))
         # Default 
         self.textctrl.StyleSetSpec(STC_P_DEFAULT, "fore:#000000,face:%(mono)s,size:%(size)d" % faces)
@@ -395,7 +399,10 @@ class WorldEditorWindow(EditorWindow):
     def __init__(self,gui):
         self.wxext = "World files (*.wld)|*.wld| All files (*.*)|*.*"
         self.ext = ".wld"
-        self.kwords = [_('Robot'), _('Wall'), _('Beepers'), _('Size')]
+        self.kwords = [L2U(_('ROBOT')).title(), L2U(_('WALL')).title(),\
+                    L2U(_('BEEPERS')).title(), L2U(_('SIZE')).title()]
+        #self.kwords = [L2U(_('Robot')), L2U(_('Wall')), L2U(_('Beepers')), L2U(_('Size'))]
+        print "kwords",self.kwords
         EditorWindow.__init__(self,gui)
         file = wxMenu()
         file.Append(ID_LOADWORLD, L2U(_("&Open World for Editing...")),\
@@ -431,7 +438,10 @@ class CodeEditorWindow(EditorWindow):
     def __init__(self,gui):
         self.wxext = "GvR files (*.gvr)|*.gvr| All files (*.*)|*.*"
         self.ext = ".gvr"
-        self.kwords = gvrparser.TESTS+gvrparser.COMMANDS+gvrparser.DIV
+        
+        #self.kwords = gvrparser.TESTS+gvrparser.COMMANDS+gvrparser.DIV
+        self.kwords = gvrparser.lookup_dict.keys()
+        print "kwords from parser\n ",self.kwords
         EditorWindow.__init__(self,gui)
         file = wxMenu()
         file.Append(ID_LOADCODE, L2U(_("&Open Program for Editing...")),\
