@@ -14,7 +14,10 @@ except Exception, info:
     print "Can not import wxversion and/or select version 2.5"
     print "Will attempt to import existing version of wxPython."
 import wx
+
 from wxPython.wx import *
+#wxlocale = wx.Locale(wx.LANGUAGE_DEFAULT)
+
 from wxPython.lib.dialogs import wxScrolledMessageDialog
 
 sys.path[0] = OrgSysPath # reset path to original
@@ -22,6 +25,8 @@ from utils import *
 from version import ABOUT_TEXT
 import ConfigParser,os,shutil
 
+# Does our .gvrrc exist yet?
+gvrrcExists = os.path.exists(os.path.expanduser('~/.gvrrc'))
 setUpUnixRC()
 
 GVRREDIRECT = 0# redirect stderr and stdout to files (see out.py)
@@ -67,6 +72,8 @@ from Editorwindows import WorldEditorWindow, CodeEditorWindow
 import gvrparser
 import webbrowser
 
+import WorldBuilder
+
 GVRDEBUG = 0# set to 0 before release
 
 ID_RESET   = wxNewId()
@@ -143,9 +150,9 @@ class Application(wxFrame):
                 
         self.myStepper = None
                 
-        self.SleepDict = {_('Instant'):5, _('Fast'):50, _('Medium'):150, _('Slow'):500}
+        self.SleepDict = {L2U(_('Instant')):5, L2U(_('Fast')):50, L2U(_('Medium')):150, L2U(_('Slow')):500}
         self.sleepHighlight = 1
-        self.setSpeed(_('Medium'))
+        self.setSpeed(L2U(_('Medium')))
 
         file   = wxMenu()
         self.addMenuEvent(file, self.menuNewWorld,\
@@ -172,15 +179,17 @@ class Application(wxFrame):
         self.worldwindowmenu = self.addMenuEvent(window, self.menuWorldWindow,\
                                 L2U(_("&World Window")),\
                                 L2U(_("Show/Hide the World Window")), 1)
-
+        self.worldbuildermenu = self.addMenuEvent(window, self.menuWorldBuilder,\
+                                L2U(_("&World Builder")),\
+                                L2U(_("Show/Hide the World Builder")), 1)
         setup  = wxMenu()
         self.addMenuEvent(setup, self.menuSetSpeed, 
-            _("Set S&peed..."), _("Change the time Guido pauses between moves"))
+          L2U(_("Set S&peed...")), L2U(_("Change the time Guido pauses between moves")))
         # we use this only on windows, other platforms must edit the gvrrc file
         # located in the users home directory
         if os.name == 'nt':
             self.addMenuEvent(setup, self.menuSetLanguage, 
-                _("Set Language..."), _("Change the language used"))
+                L2U(_("Set Language...")), L2U(_("Change the language used")))
         
         help   = wxMenu()
         self.addMenuEvent(help, self.menuGvrLessons,\
@@ -203,12 +212,14 @@ class Application(wxFrame):
         
         self.codeEditorWindow = None
         self.worldEditorWindow = None
-
+        self.worldBuilder = None
+        
         EVT_PAINT(self, self.OnPaint)
         EVT_ERASE_BACKGROUND(self, self.DoNothing)
         EVT_MOVE(self, self.Move)
         EVT_SIZE(self, self.Size)
         EVT_CLOSE(self, self.menuExit)
+        
         timerId = wxNewId()
         self.Mytimer = wxTimer(self,timerId)
         EVT_TIMER(self,timerId,self.stepThruNextInstruction)
@@ -227,6 +238,10 @@ class Application(wxFrame):
                                     title=L2U(_("Choose a program to open")),\
                                     file = programFile)            
 
+    def OnDestroy(self, *args):
+        print "ondestroy"
+        wxMessageBox(L2U(_("Please use the 'quit' option in the 'file' menu")))
+    
     def addMenuEvent(self, menu, callbackMethod, label, tooltip, checked=0):
         id = wxNewId()
         EVT_MENU(self, id, callbackMethod)
@@ -277,7 +292,10 @@ class Application(wxFrame):
             self.worldEditorWindow.TimeToQuit('NoRefresh')
         if self.codeEditorWindow:
             self.codeEditorWindow.TimeToQuit('NoRefresh')
+        if self.worldBuilder:
+            self.worldBuilder.Quit()
         self.Destroy()
+        sys.exit(0)        
         
     def menuProgramWindow(self, *args):
         if not self.codeEditorWindow:
@@ -295,6 +313,11 @@ class Application(wxFrame):
         else:
             self.worldEditorWindow.hide_me()
             
+    def menuWorldBuilder(self,*args):
+        if not self.worldBuilder:
+            self.worldBuilder = WorldBuilder.GUI(None,self)
+            
+    
     def ResetEditorWindows(self,name):   
         """Called from the editorwindows"""
         if name == "codewindow":
@@ -352,7 +375,7 @@ class Application(wxFrame):
                 txt = str(info)+ '\n'+ "Be sure to set your env. variable 'BROWSER' to your preffered browser."
                 wxMessageBox(txt)
         else: 
-            wxMessageBox(L2U(_("Can't find the lessons.\nMake sure you have installed the GvR-Lessons package.\nCheck the GvR website for the lessons package.\nwww.gvr.sf.net")),"Can't open the GvR lessons")
+            wxMessageBox(L2U(_("Can't find the lessons.\nMake sure you have installed the GvR-Lessons package.\nCheck the GvR website for the lessons package.\nhttp://gvr.sf.net")),"Can't open the GvR lessons")
     
     def menuGvrLanguageReference(self,*args):
         """ Display a messagebox with the language reference"""
@@ -417,7 +440,7 @@ class Application(wxFrame):
 
     def Abort(self, *event):
         self.stopTimer()# needed for win32
-        self.debug(_('User aborted program')+'\n'+self.myStepper.stackTrace())
+        self.debug(L2U(_('User aborted program'))+'\n'+self.myStepper.stackTrace())
         self.stopRobot()
 
     def beginProgram(self):
@@ -458,14 +481,14 @@ class Application(wxFrame):
                 self.startTimer()
         except guiWorld.TurnedOffException:
             self.stopRobot()
-            self.debug(_('Robot turned off'))
+            self.debug(L2U(_('Robot turned off')))
         except (guiWorld.GuiWorldException,stepper.OutOfInstructionsException),e:
             self.stopRobot()
             self.debug(str(e))
         except Breakpoint:
             ## XXX This doesn't work properly
             ## the timer stops, but the robots walks further
-            self.debug(_('Hit execute to resume'))
+            self.debug(L2U(_('Hit execute to resume')))
             self.stopTimer()
         except stepper.InfiniteLoopException,info:
             # special message, don't translate
@@ -626,7 +649,7 @@ class TextWindow(wxFrame):
 
 def setUpUnixDirs():
     if not os.path.exists(os.path.expanduser('~/GvR/')):
-        choice = wxMessageDialog(None, _('Would you like to create default directories for your worlds and programs? ')+'(~/GvR)', 'GvR-Question', wxYES_NO)
+        choice = wxMessageDialog(None, L2U(_('Would you like to create default directories for your worlds and programs? '))+'(~/GvR)', 'GvR-Question', wxYES_NO)
         if choice.ShowModal() == wxID_YES:
             choice.Destroy()
             try:
@@ -638,17 +661,17 @@ def setUpUnixDirs():
             except Exception,info:
                 wxMessageBox(L2U(_("Can't make the default directory.\n The error message was: %s")) % info,"GvR-ERROR")   
     
-class MyApp(wxApp):
-    """Not longer used, see 'if __name__ ==....etc.'"""
-    def __init__(self, foo, worldFile, programFile):
-        self.worldFile = worldFile
-        self.programFile = programFile
-        wxApp.__init__(self, foo)
-
-    def OnInit(self):
-        # XXX do we need this OnInit stuff anymore ?? Stas Z
-        pass
-        return true
+##class MyApp(wxApp):
+##    """Not longer used, see 'if __name__ ==....etc.'"""
+##    def __init__(self, foo, worldFile, programFile):
+##        self.worldFile = worldFile
+##        self.programFile = programFile
+##        wxApp.__init__(self, foo)
+##
+##    def OnInit(self):
+##        # XXX do we need this OnInit stuff anymore ?? Stas Z
+##        pass
+##        return true
 
 if __name__ == '__main__':
     try:
@@ -661,7 +684,9 @@ if __name__ == '__main__':
         #app = MyApp(0, worldFile, programFile)
         app = wxPySimpleApp() 
         gvrWindow = Application(NULL, -1, "Guido van Robot", worldFile, programFile)
-        if os.name == 'posix' and not isOsX(): setUpUnixDirs()
+        # If .gvrrc exists, don't ask us if we want to make GvR dirs again
+        # (since we've clearly run once before and been asked)
+        if os.name == 'posix' and not isOsX() and not gvrrcExists: setUpUnixDirs()
         if LocaleMesg[0]: wxMessageBox(LocaleMesg[0],"GvR info")
         gvrWindow.Centre()
         gvrWindow.Show(true)
